{ config, ... }:

{
  imports = [ (import ./hardware-configuration.nix) ];

  boot.loader = {
    efi = {
      canTouchEfiVariables = true;
      efiSysMountPoint = "/boot";
    };
    grub = {
      efiSupport = true;
      device = "nodev";
      useOSProber = true;
    };
  };

  services.tailscale.enable = true;
  networking.nameservers = [ "100.100.100.100" ];
  networking.search = [ "junko-dace.ts.net" ];

  networking.firewall = {
    checkReversePath = "loose";
    trustedInterfaces = [ "tailscale0" ];
    allowedUDPPorts = [ config.services.tailscale.port ];
  };

  # Use X11 caps lock to escape remap in TTY
  console.useXkbConfig = true;
  services.xserver.xkbOptions = "caps:escape";

  services.xserver.libinput = {
    enable = true;
    touchpad.tapping = true;
  };

  services.blueman.enable = true;

  # audio controls and polybar module don't work on pipewire
  # hardware.pulseaudio = {
  #  enable = true;
  #  support32Bit = true;
  # };
  # services.pipewire.enable = false;
}
